@@ -13,14 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from copy import deepcopy
-from enum import IntEnum
-
 import os
 import shutil
-from iconcommons.logger import Logger
+from copy import deepcopy
+from enum import IntEnum
 from typing import TYPE_CHECKING, List, Optional, Tuple, Dict, Union, Any
 
+from iconcommons.logger import Logger
+
 from iconservice.rollback import check_backup_exists
 from iconservice.rollback.backup_cleaner import BackupCleaner
 from iconservice.rollback.backup_manager import BackupManager
@@ -82,6 +82,7 @@ from .utils import sha3_256, int_to_bytes, ContextEngine, ContextStorage
 from .utils import to_camel_case, bytes_to_hex
 from .utils.bloom import BloomFilter
 from .utils.timer import Timer
+from .utils.locked import is_address_locked
 
 if TYPE_CHECKING:
     from .iconscore.icon_score_event_log import EventLog
@@ -719,8 +720,8 @@ class IconServiceEngine(ContextContainer):
                                                                            prev_block_generator,
                                                                            prev_block_votes,
                                                                            rc_db_revision)
-        context.update_batch()
         context.storage.meta.put_prep_address_converter(context, context.prep_address_converter)
+        context.update_batch()
 
         if next_preps is not None:
             Logger.info(tag="TERM", msg=f"{next_preps}")
@@ -753,7 +754,7 @@ class IconServiceEngine(ContextContainer):
 
         for address, vote_state in validators:
             dirty_prep: Optional['PRep'] = context.get_prep(address, mutable=True)
-            assert isinstance(dirty_prep, PRep)
+            assert isinstance(dirty_prep, PRep), f"dirty_prep: {address}"
 
             is_validator: bool = vote_state != BlockVoteStatus.NONE.value
 
@@ -776,7 +777,7 @@ class IconServiceEngine(ContextContainer):
             return
 
         dirty_prep: 'PRep' = context.get_prep(prev_block_generator, mutable=True)
-        assert isinstance(dirty_prep, PRep)
+        assert isinstance(dirty_prep, PRep), f"dirty_prep: {address}"
 
         dirty_prep.last_generate_block_height = context.block.height - 1
         context.put_dirty_prep(dirty_prep)
